~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Mastercard plugin for ofxstatement
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This project provides a plugin for ofxstatement that imports German Mastercard statements.

`ofxstatement`_ is a tool to convert proprietary bank statement to OFX format, suitable for importing to GnuCash and other programs.

.. _ofxstatement: https://github.com/kedder/ofxstatement

Whilst the plugin was developed for statements created by Sparkasse, it should work for all German Mastercard statements.
Tested with statements named:

* `1234xxxxxxxx5678_Abrechnung_vom_DD_MM_YYYY_Last_First.PDF`
* `YYYYMMDD_1234xxxxxxxx5678_Abrechnung_vom_DD_MM_YYYY_Last_First.PDF`
* `YYYYMMDD_1234xxxxxxxx5678_-_Ihre_Abrechnung_vom_DD_MM_YYYY.PDF`

If you encounter any errors when using this plugin, feel free to open an issue.
